@@ -10,4 +10,6 @@ pub mod prelude {
     pub use crate::fixedtimestep::{FixedTimestepInfo, FixedTimestepStage};
     #[cfg(feature = "states")]
     pub use crate::state::{CurrentState, NextState, StateTransitionStage};
+    #[cfg(feature = "app")]
+    pub use crate::state::app::AppLooplessStateExt;
 }
